# pylint: disable=too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import sys
from typing import Any, Callable, Dict, IO, List, Optional, TypeVar, Union, overload

from azure.core.exceptions import (
    ClientAuthenticationError,
    HttpResponseError,
    ResourceExistsError,
    ResourceNotFoundError,
    ResourceNotModifiedError,
    map_error,
)
from azure.core.pipeline import PipelineResponse
from azure.core.pipeline.transport import HttpResponse
from azure.core.rest import HttpRequest
from azure.core.tracing.decorator import distributed_trace
from azure.core.utils import case_insensitive_dict
from azure.mgmt.core.exceptions import ARMErrorFormat

from .. import models as _models
from .._serialization import Serializer
from .._vendor import _convert_request, _format_url_section

if sys.version_info >= (3, 8):
    from typing import Literal  # pylint: disable=no-name-in-module, ungrouped-imports
else:
    from typing_extensions import Literal  # type: ignore  # pylint: disable=ungrouped-imports
T = TypeVar("T")
ClsType = Optional[Callable[[PipelineResponse[HttpRequest, HttpResponse], T, Dict[str, Any]], Any]]

_SERIALIZER = Serializer()
_SERIALIZER.client_side_validation = False


def build_create_or_update_request(
    resource_group_name: str, service_topology_name: str, service_name: str, subscription_id: str, **kwargs: Any
) -> HttpRequest:
    _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
    _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

    api_version = kwargs.pop(
        "api_version", _params.pop("api-version", "2019-11-01-preview")
    )  # type: Literal["2019-11-01-preview"]
    content_type = kwargs.pop("content_type", _headers.pop("Content-Type", None))  # type: Optional[str]
    accept = _headers.pop("Accept", "application/json")

    # Construct URL
    _url = kwargs.pop(
        "template_url",
        "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/serviceTopologies/{serviceTopologyName}/services/{serviceName}",
    )  # pylint: disable=line-too-long
    path_format_arguments = {
        "subscriptionId": _SERIALIZER.url("subscription_id", subscription_id, "str"),
        "resourceGroupName": _SERIALIZER.url(
            "resource_group_name", resource_group_name, "str", max_length=90, min_length=1, pattern=r"^[-\w\._\(\)]+$"
        ),
        "serviceTopologyName": _SERIALIZER.url("service_topology_name", service_topology_name, "str"),
        "serviceName": _SERIALIZER.url("service_name", service_name, "str"),
    }

    _url = _format_url_section(_url, **path_format_arguments)

    # Construct parameters
    _params["api-version"] = _SERIALIZER.query("api_version", api_version, "str")

    # Construct headers
    if content_type is not None:
        _headers["Content-Type"] = _SERIALIZER.header("content_type", content_type, "str")
    _headers["Accept"] = _SERIALIZER.header("accept", accept, "str")

    return HttpRequest(method="PUT", url=_url, params=_params, headers=_headers, **kwargs)


def build_get_request(
    resource_group_name: str, service_topology_name: str, service_name: str, subscription_id: str, **kwargs: Any
) -> HttpRequest:
    _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
    _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

    api_version = kwargs.pop(
        "api_version", _params.pop("api-version", "2019-11-01-preview")
    )  # type: Literal["2019-11-01-preview"]
    accept = _headers.pop("Accept", "application/json")

    # Construct URL
    _url = kwargs.pop(
        "template_url",
        "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/serviceTopologies/{serviceTopologyName}/services/{serviceName}",
    )  # pylint: disable=line-too-long
    path_format_arguments = {
        "subscriptionId": _SERIALIZER.url("subscription_id", subscription_id, "str"),
        "resourceGroupName": _SERIALIZER.url(
            "resource_group_name", resource_group_name, "str", max_length=90, min_length=1, pattern=r"^[-\w\._\(\)]+$"
        ),
        "serviceTopologyName": _SERIALIZER.url("service_topology_name", service_topology_name, "str"),
        "serviceName": _SERIALIZER.url("service_name", service_name, "str"),
    }

    _url = _format_url_section(_url, **path_format_arguments)

    # Construct parameters
    _params["api-version"] = _SERIALIZER.query("api_version", api_version, "str")

    # Construct headers
    _headers["Accept"] = _SERIALIZER.header("accept", accept, "str")

    return HttpRequest(method="GET", url=_url, params=_params, headers=_headers, **kwargs)


def build_delete_request(
    resource_group_name: str, service_topology_name: str, service_name: str, subscription_id: str, **kwargs: Any
) -> HttpRequest:
    _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
    _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

    api_version = kwargs.pop(
        "api_version", _params.pop("api-version", "2019-11-01-preview")
    )  # type: Literal["2019-11-01-preview"]
    accept = _headers.pop("Accept", "application/json")

    # Construct URL
    _url = kwargs.pop(
        "template_url",
        "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/serviceTopologies/{serviceTopologyName}/services/{serviceName}",
    )  # pylint: disable=line-too-long
    path_format_arguments = {
        "subscriptionId": _SERIALIZER.url("subscription_id", subscription_id, "str"),
        "resourceGroupName": _SERIALIZER.url(
            "resource_group_name", resource_group_name, "str", max_length=90, min_length=1, pattern=r"^[-\w\._\(\)]+$"
        ),
        "serviceTopologyName": _SERIALIZER.url("service_topology_name", service_topology_name, "str"),
        "serviceName": _SERIALIZER.url("service_name", service_name, "str"),
    }

    _url = _format_url_section(_url, **path_format_arguments)

    # Construct parameters
    _params["api-version"] = _SERIALIZER.query("api_version", api_version, "str")

    # Construct headers
    _headers["Accept"] = _SERIALIZER.header("accept", accept, "str")

    return HttpRequest(method="DELETE", url=_url, params=_params, headers=_headers, **kwargs)


def build_list_request(
    resource_group_name: str, service_topology_name: str, subscription_id: str, **kwargs: Any
) -> HttpRequest:
    _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
    _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

    api_version = kwargs.pop(
        "api_version", _params.pop("api-version", "2019-11-01-preview")
    )  # type: Literal["2019-11-01-preview"]
    accept = _headers.pop("Accept", "application/json")

    # Construct URL
    _url = kwargs.pop(
        "template_url",
        "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/serviceTopologies/{serviceTopologyName}/services",
    )  # pylint: disable=line-too-long
    path_format_arguments = {
        "subscriptionId": _SERIALIZER.url("subscription_id", subscription_id, "str"),
        "resourceGroupName": _SERIALIZER.url(
            "resource_group_name", resource_group_name, "str", max_length=90, min_length=1, pattern=r"^[-\w\._\(\)]+$"
        ),
        "serviceTopologyName": _SERIALIZER.url("service_topology_name", service_topology_name, "str"),
    }

    _url = _format_url_section(_url, **path_format_arguments)

    # Construct parameters
    _params["api-version"] = _SERIALIZER.query("api_version", api_version, "str")

    # Construct headers
    _headers["Accept"] = _SERIALIZER.header("accept", accept, "str")

    return HttpRequest(method="GET", url=_url, params=_params, headers=_headers, **kwargs)


class ServicesOperations:
    """
    .. warning::
        **DO NOT** instantiate this class directly.

        Instead, you should access the following operations through
        :class:`~azure.mgmt.deploymentmanager.AzureDeploymentManager`'s
        :attr:`services` attribute.
    """

    models = _models

    def __init__(self, *args, **kwargs):
        input_args = list(args)
        self._client = input_args.pop(0) if input_args else kwargs.pop("client")
        self._config = input_args.pop(0) if input_args else kwargs.pop("config")
        self._serialize = input_args.pop(0) if input_args else kwargs.pop("serializer")
        self._deserialize = input_args.pop(0) if input_args else kwargs.pop("deserializer")

    @overload
    def create_or_update(
        self,
        resource_group_name: str,
        service_topology_name: str,
        service_name: str,
        service_info: _models.ServiceResource,
        *,
        content_type: str = "application/json",
        **kwargs: Any
    ) -> _models.ServiceResource:
        """Creates or updates a service in the service topology.

        Synchronously creates a new service or updates an existing service.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param service_topology_name: The name of the service topology . Required.
        :type service_topology_name: str
        :param service_name: The name of the service resource. Required.
        :type service_name: str
        :param service_info: The service object. Required.
        :type service_info: ~azure.mgmt.deploymentmanager.models.ServiceResource
        :keyword content_type: Body Parameter content-type. Content type parameter for JSON body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: ServiceResource or the result of cls(response)
        :rtype: ~azure.mgmt.deploymentmanager.models.ServiceResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @overload
    def create_or_update(
        self,
        resource_group_name: str,
        service_topology_name: str,
        service_name: str,
        service_info: IO,
        *,
        content_type: str = "application/json",
        **kwargs: Any
    ) -> _models.ServiceResource:
        """Creates or updates a service in the service topology.

        Synchronously creates a new service or updates an existing service.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param service_topology_name: The name of the service topology . Required.
        :type service_topology_name: str
        :param service_name: The name of the service resource. Required.
        :type service_name: str
        :param service_info: The service object. Required.
        :type service_info: IO
        :keyword content_type: Body Parameter content-type. Content type parameter for binary body.
         Default value is "application/json".
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: ServiceResource or the result of cls(response)
        :rtype: ~azure.mgmt.deploymentmanager.models.ServiceResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """

    @distributed_trace
    def create_or_update(
        self,
        resource_group_name: str,
        service_topology_name: str,
        service_name: str,
        service_info: Union[_models.ServiceResource, IO],
        **kwargs: Any
    ) -> _models.ServiceResource:
        """Creates or updates a service in the service topology.

        Synchronously creates a new service or updates an existing service.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param service_topology_name: The name of the service topology . Required.
        :type service_topology_name: str
        :param service_name: The name of the service resource. Required.
        :type service_name: str
        :param service_info: The service object. Is either a model type or a IO type. Required.
        :type service_info: ~azure.mgmt.deploymentmanager.models.ServiceResource or IO
        :keyword content_type: Body Parameter content-type. Known values are: 'application/json'.
         Default value is None.
        :paramtype content_type: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: ServiceResource or the result of cls(response)
        :rtype: ~azure.mgmt.deploymentmanager.models.ServiceResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = case_insensitive_dict(kwargs.pop("headers", {}) or {})
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version = kwargs.pop(
            "api_version", _params.pop("api-version", self._config.api_version)
        )  # type: Literal["2019-11-01-preview"]
        content_type = kwargs.pop("content_type", _headers.pop("Content-Type", None))  # type: Optional[str]
        cls = kwargs.pop("cls", None)  # type: ClsType[_models.ServiceResource]

        content_type = content_type or "application/json"
        _json = None
        _content = None
        if isinstance(service_info, (IO, bytes)):
            _content = service_info
        else:
            _json = self._serialize.body(service_info, "ServiceResource")

        request = build_create_or_update_request(
            resource_group_name=resource_group_name,
            service_topology_name=service_topology_name,
            service_name=service_name,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            content_type=content_type,
            json=_json,
            content=_content,
            template_url=self.create_or_update.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)  # type: ignore

        pipeline_response = self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            request, stream=False, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [201]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            raise HttpResponseError(response=response, error_format=ARMErrorFormat)

        deserialized = self._deserialize("ServiceResource", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    create_or_update.metadata = {"url": "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/serviceTopologies/{serviceTopologyName}/services/{serviceName}"}  # type: ignore

    @distributed_trace
    def get(
        self, resource_group_name: str, service_topology_name: str, service_name: str, **kwargs: Any
    ) -> _models.ServiceResource:
        """Gets the service.

        Gets the service.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param service_topology_name: The name of the service topology . Required.
        :type service_topology_name: str
        :param service_name: The name of the service resource. Required.
        :type service_name: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: ServiceResource or the result of cls(response)
        :rtype: ~azure.mgmt.deploymentmanager.models.ServiceResource
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = kwargs.pop("headers", {}) or {}
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version = kwargs.pop(
            "api_version", _params.pop("api-version", self._config.api_version)
        )  # type: Literal["2019-11-01-preview"]
        cls = kwargs.pop("cls", None)  # type: ClsType[_models.ServiceResource]

        request = build_get_request(
            resource_group_name=resource_group_name,
            service_topology_name=service_topology_name,
            service_name=service_name,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            template_url=self.get.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)  # type: ignore

        pipeline_response = self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            request, stream=False, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            raise HttpResponseError(response=response, error_format=ARMErrorFormat)

        deserialized = self._deserialize("ServiceResource", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    get.metadata = {"url": "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/serviceTopologies/{serviceTopologyName}/services/{serviceName}"}  # type: ignore

    @distributed_trace
    def delete(  # pylint: disable=inconsistent-return-statements
        self, resource_group_name: str, service_topology_name: str, service_name: str, **kwargs: Any
    ) -> None:
        """Deletes the service.

        Deletes the service.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param service_topology_name: The name of the service topology . Required.
        :type service_topology_name: str
        :param service_name: The name of the service resource. Required.
        :type service_name: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: None or the result of cls(response)
        :rtype: None
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = kwargs.pop("headers", {}) or {}
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version = kwargs.pop(
            "api_version", _params.pop("api-version", self._config.api_version)
        )  # type: Literal["2019-11-01-preview"]
        cls = kwargs.pop("cls", None)  # type: ClsType[None]

        request = build_delete_request(
            resource_group_name=resource_group_name,
            service_topology_name=service_topology_name,
            service_name=service_name,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            template_url=self.delete.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)  # type: ignore

        pipeline_response = self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            request, stream=False, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200, 204]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            raise HttpResponseError(response=response, error_format=ARMErrorFormat)

        if cls:
            return cls(pipeline_response, None, {})

    delete.metadata = {"url": "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/serviceTopologies/{serviceTopologyName}/services/{serviceName}"}  # type: ignore

    @distributed_trace
    def list(
        self, resource_group_name: str, service_topology_name: str, **kwargs: Any
    ) -> List[_models.ServiceResource]:
        """Lists the services in the service topology.

        Lists the services in the service topology.

        :param resource_group_name: The name of the resource group. The name is case insensitive.
         Required.
        :type resource_group_name: str
        :param service_topology_name: The name of the service topology . Required.
        :type service_topology_name: str
        :keyword callable cls: A custom type or function that will be passed the direct response
        :return: list of ServiceResource or the result of cls(response)
        :rtype: list[~azure.mgmt.deploymentmanager.models.ServiceResource]
        :raises ~azure.core.exceptions.HttpResponseError:
        """
        error_map = {
            401: ClientAuthenticationError,
            404: ResourceNotFoundError,
            409: ResourceExistsError,
            304: ResourceNotModifiedError,
        }
        error_map.update(kwargs.pop("error_map", {}) or {})

        _headers = kwargs.pop("headers", {}) or {}
        _params = case_insensitive_dict(kwargs.pop("params", {}) or {})

        api_version = kwargs.pop(
            "api_version", _params.pop("api-version", self._config.api_version)
        )  # type: Literal["2019-11-01-preview"]
        cls = kwargs.pop("cls", None)  # type: ClsType[List[_models.ServiceResource]]

        request = build_list_request(
            resource_group_name=resource_group_name,
            service_topology_name=service_topology_name,
            subscription_id=self._config.subscription_id,
            api_version=api_version,
            template_url=self.list.metadata["url"],
            headers=_headers,
            params=_params,
        )
        request = _convert_request(request)
        request.url = self._client.format_url(request.url)  # type: ignore

        pipeline_response = self._client._pipeline.run(  # type: ignore # pylint: disable=protected-access
            request, stream=False, **kwargs
        )

        response = pipeline_response.http_response

        if response.status_code not in [200]:
            map_error(status_code=response.status_code, response=response, error_map=error_map)
            raise HttpResponseError(response=response, error_format=ARMErrorFormat)

        deserialized = self._deserialize("[ServiceResource]", pipeline_response)

        if cls:
            return cls(pipeline_response, deserialized, {})

        return deserialized

    list.metadata = {"url": "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DeploymentManager/serviceTopologies/{serviceTopologyName}/services"}  # type: ignore



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    AssignDeploymentResourcesDetails,
    AssignedDeploymentResource,
    AssignedProjectDeploymentMetadata,
    AssignedProjectDeploymentsMetadata,
    ConfusionMatrixCell,
    ConfusionMatrixRow,
    CopyProjectDetails,
    CopyProjectState,
    CreateDeploymentDetails,
    CreateProjectOptions,
    CustomEntityRecognitionDocumentEvalResult,
    CustomEntityRecognitionEvalSummary,
    CustomHealthcareDocumentEvalResult,
    CustomHealthcareEvalSummary,
    CustomMultiLabelClassificationDocumentEvalResult,
    CustomMultiLabelClassificationEvalSummary,
    CustomSingleLabelClassificationDocumentEvalResult,
    CustomSingleLabelClassificationEvalSummary,
    CustomTextSentimentDocumentEvalResult,
    CustomTextSentimentEvalSummary,
    CustomTextSentimentProjectAssets,
    DataGenerationConnectionInfo,
    DataGenerationSetting,
    DeleteDeploymentDetails,
    DeploymentDeleteFromResourcesState,
    DeploymentResource,
    DeploymentResourcesState,
    DeploymentState,
    DocumentEntityLabelEvalResult,
    DocumentEntityRecognitionEvalResult,
    DocumentEntityRegionEvalResult,
    DocumentEvalResult,
    DocumentHealthcareEvalResult,
    DocumentMultiLabelClassificationEvalResult,
    DocumentSentimentLabelEvalResult,
    DocumentSingleLabelClassificationEvalResult,
    DocumentTextSentimentEvalResult,
    EntityEvalSummary,
    EntityRecognitionEvalSummary,
    EvalSummary,
    EvaluationDetails,
    EvaluationJobResult,
    EvaluationState,
    ExportProjectState,
    ExportedClass,
    ExportedCompositeEntity,
    ExportedCustomAbstractiveSummarizationDocument,
    ExportedCustomAbstractiveSummarizationProjectAsset,
    ExportedCustomEntityRecognitionDocument,
    ExportedCustomEntityRecognitionProjectAsset,
    ExportedCustomHealthcareDocument,
    ExportedCustomHealthcareProjectAsset,
    ExportedCustomMultiLabelClassificationDocument,
    ExportedCustomMultiLabelClassificationProjectAsset,
    ExportedCustomSingleLabelClassificationDocument,
    ExportedCustomSingleLabelClassificationProjectAsset,
    ExportedCustomTextSentimentDocument,
    ExportedDocumentClass,
    ExportedDocumentEntityLabel,
    ExportedDocumentEntityRegion,
    ExportedDocumentSentimentLabel,
    ExportedEntity,
    ExportedEntityList,
    ExportedEntityListSynonym,
    ExportedEntitySublist,
    ExportedModelDetails,
    ExportedModelManifest,
    ExportedModelState,
    ExportedPrebuiltEntity,
    ExportedProject,
    ExportedProjectAsset,
    ExportedTrainedModel,
    ImportProjectState,
    LoadSnapshotState,
    ModelFile,
    MultiLabelClassEvalSummary,
    MultiLabelClassificationEvalSummary,
    PrebuiltEntity,
    ProjectDeletionState,
    ProjectDeployment,
    ProjectDetails,
    ProjectSettings,
    ProjectTrainedModel,
    ResourceMetadata,
    SentimentEvalSummary,
    SingleLabelClassEvalSummary,
    SingleLabelClassificationEvalSummary,
    SpanSentimentEvalSummary,
    SubTrainingState,
    SupportedLanguage,
    SwapDeploymentsDetails,
    SwapDeploymentsState,
    TextSentimentEvalSummary,
    TrainingConfigVersion,
    TrainingJobDetails,
    TrainingJobResult,
    TrainingState,
    UnassignDeploymentResourcesDetails,
)

from ._enums import (  # type: ignore
    CompositionMode,
    EvaluationKind,
    OperationStatus,
    ProjectKind,
    Sentiment,
    StringIndexType,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AssignDeploymentResourcesDetails",
    "AssignedDeploymentResource",
    "AssignedProjectDeploymentMetadata",
    "AssignedProjectDeploymentsMetadata",
    "ConfusionMatrixCell",
    "ConfusionMatrixRow",
    "CopyProjectDetails",
    "CopyProjectState",
    "CreateDeploymentDetails",
    "CreateProjectOptions",
    "CustomEntityRecognitionDocumentEvalResult",
    "CustomEntityRecognitionEvalSummary",
    "CustomHealthcareDocumentEvalResult",
    "CustomHealthcareEvalSummary",
    "CustomMultiLabelClassificationDocumentEvalResult",
    "CustomMultiLabelClassificationEvalSummary",
    "CustomSingleLabelClassificationDocumentEvalResult",
    "CustomSingleLabelClassificationEvalSummary",
    "CustomTextSentimentDocumentEvalResult",
    "CustomTextSentimentEvalSummary",
    "CustomTextSentimentProjectAssets",
    "DataGenerationConnectionInfo",
    "DataGenerationSetting",
    "DeleteDeploymentDetails",
    "DeploymentDeleteFromResourcesState",
    "DeploymentResource",
    "DeploymentResourcesState",
    "DeploymentState",
    "DocumentEntityLabelEvalResult",
    "DocumentEntityRecognitionEvalResult",
    "DocumentEntityRegionEvalResult",
    "DocumentEvalResult",
    "DocumentHealthcareEvalResult",
    "DocumentMultiLabelClassificationEvalResult",
    "DocumentSentimentLabelEvalResult",
    "DocumentSingleLabelClassificationEvalResult",
    "DocumentTextSentimentEvalResult",
    "EntityEvalSummary",
    "EntityRecognitionEvalSummary",
    "EvalSummary",
    "EvaluationDetails",
    "EvaluationJobResult",
    "EvaluationState",
    "ExportProjectState",
    "ExportedClass",
    "ExportedCompositeEntity",
    "ExportedCustomAbstractiveSummarizationDocument",
    "ExportedCustomAbstractiveSummarizationProjectAsset",
    "ExportedCustomEntityRecognitionDocument",
    "ExportedCustomEntityRecognitionProjectAsset",
    "ExportedCustomHealthcareDocument",
    "ExportedCustomHealthcareProjectAsset",
    "ExportedCustomMultiLabelClassificationDocument",
    "ExportedCustomMultiLabelClassificationProjectAsset",
    "ExportedCustomSingleLabelClassificationDocument",
    "ExportedCustomSingleLabelClassificationProjectAsset",
    "ExportedCustomTextSentimentDocument",
    "ExportedDocumentClass",
    "ExportedDocumentEntityLabel",
    "ExportedDocumentEntityRegion",
    "ExportedDocumentSentimentLabel",
    "ExportedEntity",
    "ExportedEntityList",
    "ExportedEntityListSynonym",
    "ExportedEntitySublist",
    "ExportedModelDetails",
    "ExportedModelManifest",
    "ExportedModelState",
    "ExportedPrebuiltEntity",
    "ExportedProject",
    "ExportedProjectAsset",
    "ExportedTrainedModel",
    "ImportProjectState",
    "LoadSnapshotState",
    "ModelFile",
    "MultiLabelClassEvalSummary",
    "MultiLabelClassificationEvalSummary",
    "PrebuiltEntity",
    "ProjectDeletionState",
    "ProjectDeployment",
    "ProjectDetails",
    "ProjectSettings",
    "ProjectTrainedModel",
    "ResourceMetadata",
    "SentimentEvalSummary",
    "SingleLabelClassEvalSummary",
    "SingleLabelClassificationEvalSummary",
    "SpanSentimentEvalSummary",
    "SubTrainingState",
    "SupportedLanguage",
    "SwapDeploymentsDetails",
    "SwapDeploymentsState",
    "TextSentimentEvalSummary",
    "TrainingConfigVersion",
    "TrainingJobDetails",
    "TrainingJobResult",
    "TrainingState",
    "UnassignDeploymentResourcesDetails",
    "CompositionMode",
    "EvaluationKind",
    "OperationStatus",
    "ProjectKind",
    "Sentiment",
    "StringIndexType",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
